<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="214"/>
        <source>Drop Error</source>
        <translation>Збій при розміщенні</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="215"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Файл/URL &apos;%1&apos; зараз не вдається додати до швидкого запуску</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="321"/>
        <source>Drop application
icons here</source>
        <translation>Тут значок програми
розміщення</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>Move left</source>
        <translation>Посунути ліворуч</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="58"/>
        <source>Move right</source>
        <translation>Посунути праворуч</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="62"/>
        <source>Remove from quicklaunch</source>
        <translation>Вилучити зі швидкого запуску</translation>
    </message>
</context>
</TS>
